% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

% Citrate Synthase (EC 4.1.3.7)
% First reaction in the TCA cycle.

clear all;

%% Setting up and running Example 1
% (1.) Setting parameter values (no buffering)
B_X   = 0;      % Additional proton buffering capacity
K_BX = 1e-7;    % Dissociation constant of additional proton buffer
par(1) = 0.0001;     % Vmf_ACON
T = 25;             % Temperature

% (2.) Setting initial values
xo(1) = 5e-3;       % Oxaloacetate (M)
xo(2) = 4e-3;       % AcetylcoA (M)
xo(3) = 0;          % COAS (M)
xo(4) = 1e-3;       % Citrate (M)
xo(5) = 0;          % ATP (M)
xo(6) = 0;          % ADP (M)
xo(7) = 0;          % AMP (M)
xo(8) = 0;          % SuccinylcoA (M)
xo(9)  = 1e-7;      % [H] (M)
xo(10) = 1e-3;      % [Mg] (M)
xo(11) = 150e-3;    % [K] (M)

% (3.) Running for 15-second time course
[t,x] = ode15s(@CTS,[0 15],xo,[],T,B_X,K_BX,par);
% (4.) Plotting results
figure(1); p = plot(t,x(:,1)*1e3,'k-',t,x(:,2)*1e3,'k:',t,x(:,3)*1e3,'ko',t,x(:,4)*1e3,'kx');
set(p,'linewidth',1.5);
text(3.7,4.75,'Oxaloacetate','Fontsize',14);
text(3.7,3.75,'AcetylcoA','Fontsize',14);
text(3,.75,'COAS','Fontsize',14);
text(3,1.75,'Citrate','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(3); p = plot(t,-log10(x(:,9)),'k-','LineWidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);

Table = array2table([t,x],'variableNames',{'Time','BISEN_Oxa','BISEN_Acetyl', 'BISEN_COAS', 'BISEN_Cit','BISEN_ATP','BISEN_ADP','BISEN_AMP','BISEN_SucCoA','BISEN_H','BISEN_Mg','BISEN_K'});
S1 = 'CTSBisenOutput';
S2 = '.csv';
filename1 = strcat(S1);  % Append runtime to filename
filename = strcat(filename1,S2);
%filename = 'CTSBisenOutput.csv';
writetable(Table,filename);
%%
